Coverage for audoma_api/migrations/0005_auto_20220706_1013.py: 0%

1# Generated by Django 3.2.12 on 2022-07-06 10:13

2

3 import django.db.models.deletion

4 from django.db import (

5 migrations,

6 models,

7)

8

9 import audoma.django.db.fields

10

11

12 class Migration(migrations.Migration):

13

14 dependencies = [

15 ("audoma_api", "0004_merge_20220620_1037"),

16 ]

17

18 operations = [

19 migrations.CreateModel(

20 name="Country",

21 fields=[

22 (

23 "id",

24 models.BigAutoField(

25 auto_created=True,

26 primary_key=True,

27 serialize=False,

28 verbose_name="ID",

29 ),

30 ),

31 ("name", audoma.django.db.fields.CharField(max_length=225)),

32 ],

33 ),

34 migrations.RemoveField(

35 model_name="exampletagmodel",

36 name="item",

37 ),

38 migrations.DeleteModel(

39 name="ExampleSimpleModel",

40 ),

41 migrations.DeleteModel(

42 name="ExampleTagModel",

43 ),

44 migrations.AlterField(

45 model_name="exampleperson",

46 name="birth_country",

47 field=models.ForeignKey(

48 on_delete=django.db.models.deletion.CASCADE, to="audoma_api.country"

49 ),

50 ),

51 ]